@@ -102,7 +102,7 @@ pub fn generate(
                     .as_ref()
                     .map(|s| quote! {::std::option::Option::Some(#s)})
                     .unwrap_or_else(|| quote! {::std::option::Option::None});
-                let default = generate_default(&default, &default_with)?;
+                let default = generate_default(default, default_with)?;
                 let schema_default = default
                     .as_ref()
                     .map(|value| {
@@ -122,7 +122,7 @@ pub fn generate(
                     None => quote!(::std::option::Option::None),
                 };
 
-                let visible = visible_fn(&visible);
+                let visible = visible_fn(visible);
                 schema_args.push(quote! {
                     args.insert(#name, #crate_name::registry::MetaInputValue {
                         name: #name,
@@ -180,7 +180,7 @@ pub fn generate(
                                 .iter()
                                 .find(|(pat_ident, _, _)| pat_ident.ident == variable)
                             {
-                                let default = match generate_default(&default, &default_with)? {
+                                let default = match generate_default(default, default_with)? {
                                     Some(default) => {
                                         quote! { ::std::option::Option::Some(|| -> #ty { #default }) }
                                     }
